import Component from '@ember/component';
import layout from '../templates/components/ui-sortable';
import {get, set} from '@ember/object';
import Sortable from 'sortable';

export default Component.extend({
  layout,

  init() {
    this._options = {
      sort: this.getWithDefault('sort', true),
      store: this.getWithDefault('store', null),
      dataIdAttr: this.getWithDefault('dataAttr', 'data-id'),
      delay: this.getWithDefault('delay', 0),
      animation: this.getWithDefault('animation', 200),
      disabled: this.getWithDefault('disabled', false),
      handle: this.getWithDefault('handle', null),
      forceFallback: this.getWithDefault('fallback', false),
      ghostClass: this.getWithDefault('ghost', 'ui-sortable-ghost'),
      chosenClass: this.getWithDefault('chosen', 'ui-sortable-chosen'),
      dragClass: this.getWithDefault('dragging', 'ui-sortable-dragging'),
      fallbackClass: this.getWithDefault('fallbackClass', 'ui-sortable-fallback'),
    };

    [
      'setData',
      'onChoose',
      'onStart',
      'onEnd',
      'onAdd',
      'onUpdate',
      'onSort',
      'onRemove',
      'onFilter',
      'onMove',
      'onClone'
    ].forEach(eventName => {
      if (get(this, eventName)) this._options[eventName] = get(this, eventName);
    });

    this._super(...arguments);
  },

  didInsertElement() {
    set(this, 'sortable', new Sortable(this.element, this._options));
  },

  didRender() {
    if (this.sortable) {
      let handle = get(this, 'handle');
      if (handle) {
        set(this, 'sortable.handle', handle);
        this.sortable.option('handle', `.${handle}`);
      }
    }
  }
});
